@@ -17,7 +17,7 @@ class LearningOutcome (Model) :
     class Meta:
         rdf_type = 'coopstarter:skills'
         view_set = I18nLDPViewSet
-        depth = 0
+        depth = 1
 
     def __str__(self):
         return self.name
@@ -73,7 +73,7 @@ class Step (Model):
         container_path = 'steps/'
         rdf_type = 'coopstarter:step'
         view_set = I18nLDPViewSet
-        depth = 0
+        depth = 1
     
     def __str__(self):
         return self.name
@@ -84,7 +84,7 @@ class Format (Model):
     class Meta:
         rdf_type = 'coopstarter:format'
         view_set = I18nLDPViewSet
-        depth = 0
+        depth = 1
 
     def __str__(self):
         return self.name
@@ -95,7 +95,7 @@ class Field (Model):
     class Meta:
         rdf_type = 'coopstarter:field'
         view_set = I18nLDPViewSet
-        depth = 0
+        depth = 1
 
     def __str__(self):
         return self.name
@@ -106,7 +106,7 @@ class Type (Model):
     class Meta:
         rdf_type = 'coopstarter:resourcetype'
         view_set = I18nLDPViewSet
-        depth = 0
+        depth = 1
 
     def __str__(self):
         return self.name
@@ -118,7 +118,7 @@ class Target (Model):
     class Meta:
         rdf_type = 'coopstarter:target'
         view_set = I18nLDPViewSet
-        depth = 0
+        depth = 1
 
     def __str__(self):
         return self.name
@@ -130,7 +130,7 @@ class SharingCriteria (Model):
     class Meta:
         rdf_type = 'coopstarter:sharingcriteria'
         view_set = I18nLDPViewSet
-        depth = 0
+        depth = 1
 
     def __str__(self):
         return self.name
@@ -138,7 +138,7 @@ class SharingCriteria (Model):
 
 class Searcher(Model):
     user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="searcher_profile", on_delete=models.DO_NOTHING)
-    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.CASCADE, related_name="searchers")
+    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.DO_NOTHING, related_name="searchers")
     
     class Meta:
         auto_author = 'user'
@@ -150,6 +150,7 @@ class Searcher(Model):
         nested_fields=["user", "organisation"]
         container_path = 'searchers/'
         rdf_type = 'coopstarter:searcher'
+        depth = 1
     
     def __str__(self):
         return self.user.get_full_name()
@@ -157,7 +158,7 @@ class Searcher(Model):
 class Contributor(Model):
     user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name="contributor_profile", on_delete=models.DO_NOTHING)
     phone = models.CharField(max_length=25, null=True, blank=True, verbose_name='Phone number')
-    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.CASCADE, related_name="contributors")
+    organisation = models.ForeignKey(Organisation, null=True, on_delete=models.DO_NOTHING, related_name="contributors")
     country = models.ForeignKey(Country, null=True, related_name="contributors", on_delete=models.DO_NOTHING)
     languages = models.ManyToManyField(Language, blank=True)
 
@@ -187,6 +188,7 @@ class Contributor(Model):
         owner_perms = ['inherit', 'change', 'control', 'delete']
         anonymous_perms = ['view']
         authenticated_perms = ['inherit', 'add']
+        depth = 1
 
     def __str__(self):
         return self.user.get_full_name()
@@ -194,7 +196,7 @@ class Contributor(Model):
 class Review (Model):
     comment =  models.TextField(verbose_name="Comment", blank=True)
     status = models.CharField(max_length=32, choices=(('pending', 'Pending'), ('inappropriate', 'Inappropriate'), ('validated', 'Validated'), ('to_improve', 'Improvement required')), verbose_name="Resource status", blank=True, null=True)
-    reviewer = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.CASCADE, related_name='reviews')
+    reviewer = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.DO_NOTHING, related_name='reviews')
 
     class Meta:
         owner_field = 'reviewer'
@@ -205,6 +207,7 @@ class Review (Model):
         owner_perms = ['inherit', 'change', 'control', 'delete']
         container_path = 'reviews/'
         rdf_type = 'coopstarter:review'
+        depth = 1
 
     def __str__(self):
         return self.comment
@@ -231,11 +234,10 @@ class Resource (Model):
     target = models.ForeignKey(Target, verbose_name="Target audience", blank=True, null=True, on_delete=models.DO_NOTHING)
     type = models.ManyToManyField(Type, blank=True, verbose_name="Type of content", related_name='resources')
     sharing = models.ForeignKey(SharingCriteria, blank=True, null=True, verbose_name="Sharing profile", related_name='resources', on_delete=models.DO_NOTHING)
-
     steps = models.ManyToManyField(Step, blank=True, related_name="resources")
 
     # Relations to other models
-    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.CASCADE, related_name='resources')
+    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.DO_NOTHING, related_name='resources')
     related = models.ManyToManyField("self", blank=True)
     conversations = models.ManyToManyField(Conversation, blank=True, related_name='resources')
     likes = models.ManyToManyField(Like, blank=True, related_name='resources')
@@ -258,7 +260,7 @@ class Resource (Model):
         anonymous_perms = ['view']
         authenticated_perms = ['inherit', 'add']
         view_set = I18nLDPViewSet
-        depth = 0
+        depth = 1
 
     def __str__(self):
         return self.name
@@ -273,11 +275,11 @@ class Request (Model):
     fields = models.ManyToManyField(Field, blank=True)
     country = models.ForeignKey(Country, null=True, on_delete=models.DO_NOTHING)
 
-    organisation = models.ForeignKey(Organisation, on_delete=models.CASCADE, related_name="requests")
+    organisation = models.ForeignKey(Organisation, on_delete=models.DO_NOTHING, related_name="requests")
     skills = models.TextField(verbose_name="Learning outcomes/skills")
     
-    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.CASCADE, related_name='requests')
-    reviewer = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.CASCADE, related_name='reviewed_requests')
+    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.DO_NOTHING, related_name='requests')
+    reviewer = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, on_delete=models.DO_NOTHING, related_name='reviewed_requests')
 
     created_on = models.DateTimeField(default=timezone.now)
 
@@ -293,13 +295,14 @@ class Request (Model):
         nested_fields=["language", "fields", "organisation", "submitter", "country"]
         container_path = 'requests/'
         rdf_type = 'coopstarter:request'
+        depth = 1
         
     def __str__(self):
         return self.name
 
 class BrokenLink(Model):
-    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name="brokenlink_submitter")
-    resource = models.ForeignKey(Resource, null=True, on_delete=models.CASCADE, related_name="brokenlink_resource")
+    submitter = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.DO_NOTHING, related_name="brokenlink_submitter")
+    resource = models.ForeignKey(Resource, null=True, on_delete=models.DO_NOTHING, related_name="brokenlink_resource")
     
     class Meta:
         auto_author = 'submitter'
@@ -311,6 +314,7 @@ class BrokenLink(Model):
         nested_fields=["submitter", "resource"]
         container_path = 'brokenlinks/'
         rdf_type = 'coopstarter:brokenlinks'
+        depth = 1
     
 
 @receiver(post_save, sender=Resource)
